#!/bin/sh
# *******************************************************************
# @(#) npr/binsrc/admin/check_loader.sh npr_r3.5.2.13:cset.005708:14:14@(#)
#
# FILENAME : binscr/admin/check_loader.sh
#
# ********************************************************************
#
#                   COPYRIGHT NOTICE
#
# This file remains the intellectual property of:
#
#              Vallent Software Systems UK
#                    Spencer House
#                    23 Sheen Road
#                 Richmond, Surrey, UK
#
# Copyright (c) 2005 Vallent Software Systems UK. All rights reserved.
#
# ********************************************************************
# NPR Admin 

# ------------------------------------------------------------------------------
# Function F_exit 
# ------------------------------------------------------------------------------
F_exit()     # Error number, info+
{
  v_err=$1               # Error Number
  v_info=$2              # Error Information
  v_mess=""              # Init the error message
 
  case $v_err in
    0)  v_mess="";;
    1)  F_usage
        v_mess="Err  1 : Usage error" ;;
    2)  v_mess="Err  2 : Missing the file $v_info";;
    3)  v_mess="Err  3 : Command tqlinfo failed (return=$v_info)";;
    4)  v_mess="Err  4 : Architecture $v_info unknown";;
    5)  v_mess="Err  5 : No value for the parameter $v_info";;
   10)  v_mess="Err 10 : Received signal $v_info, terminating";;
    *)  v_mess="Err $v_err - Text : $v_info";;
  esac

  # Delete the tmp file
  # -------------------
  rm -f /tmp/*.$$

  if [ ! -z "$v_mess" ] ; then
    echo ""
    echo "$v_mess" >&2
  fi

  exit $v_err                  # Exit with status
}

# ------------------------------------------------------------------------------
# Function F_usage
# ------------------------------------------------------------------------------
F_usage()
{
  usage="Usage : check_loader.sh [-no-title] [-help|-usage] \n\
                        [-db <database> -ruleset-SIGHUP  <ruleset number> ] \n\
                        [-db <database> -ruleset-SIGTERM <ruleset number> ] \n\
                        [-db <database> -ruleset-SIGKILL <ruleset number> ] \n\
                        [-db <database> -ruleset-SIGSEGV <ruleset number> ] \n\
        \n\
        Two usages : \n\
          - Display the loader processes currently running \n\
            or listed in the configuration file. \n\
          - Kill the parameter ruleset. If the ruleset equals 0, \n\
            all the rulesets will be killed. \n\
        \n\
         e.g. \n\
              check_loader.sh \n\
              check_loader.sh -no-title \n\
              check_loader.sh -db NPRDB -ruleset-SIGTERM 3 \n\
              check_loader.sh -db NPRDB -ruleset-SIGHUP  0 \n\
        " 

  echo ""
  echo "$usage" >&2
}

# ------------------------------------------------------------------------------
# Function F_create_ps_file
# ------------------------------------------------------------------------------
F_create_ps_file()
{
  v_arch_prog=machtype
  v_arch=`$TQL_CLIENT_DIR/bin/$v_arch_prog`

  v_ps_file="/tmp/ps.$$"
  echo /dev/null > $v_ps_file

  case "$v_arch" in
    HP*)
      ps -fxu metrica | $NPR_NAWK '{ 
			    split($0, arr_args, " ")
			    v_pid=arr_args[2]
			    v_stime=arr_args[5]
			    v_time=arr_args[7]
                            v_args=substr($0,49)
                            print v_pid" "v_stime" "v_time" "v_args
                          }' | grep "nprload" | grep -v "grep" > $v_ps_file ;;
    DECALPHA)
      ps -o "pid cputime systime args" -u metrica | grep "nprload" | grep -v "grep" > $v_ps_file ;;
    SUN4SOLARIS | RS6000 | SGIRIS )
      if [ "$v_arch" -eq SUN4SOLARIS ] ; then
          VER=`uname -r`
          # SunOS 9 and greater
          if [ `echo $VER | awk -F. '{print $2}'` -gt 8 ] ; then
              PROCFILE=""
              PROCARGS=""
              PROCID=""
              TEMP=""
              # BUG 58831 remove the following line
              #rm -f $v_ps_file
              ps -o "pid stime time args" -u metrica | grep "nprload" | grep -v "grep" | while read PSINFO
              do
                  PROCID=`echo $PSINFO | awk '/^[0-9]/ { print $1 }'`
                  PROCFILE=`echo $PSINFO | awk '/^[0-9]/ { print $4 " " $5 }'`
                  PROCARGS=`pargs -a $PROCID | awk '
                      BEGIN {
                          ret = ""
                            }
                      /^argv\[1\]/ { continue }
                      /^argv\[[1-9]/ { ret = ret " " $2 }

                      END {
                            print ret
                      }'`

                  TEMP=`echo $PSINFO | awk '{ print $1 " " $2 " " $3 " " }'`
                  echo $TEMP $PROCFILE $PROCARGS >> $v_ps_file

              done
          else
              ps -o "pid stime time args" -u metrica | grep "nprload" | grep -v "grep" > $v_ps_file
          fi
      else
          ps -o "pid stime time args" -u metrica | grep "nprload" | grep -v "grep" > $v_ps_file
      fi ;;

    LINUX86 )
      ps uw | $NPR_NAWK '{ v_pid=substr($0,10,5)
                            v_stime="-"
                            v_time=substr($0,46,6)
                            gsub(" ", "", v_time)
                            v_args=substr($0,60)
                            print v_pid" "v_stime" "v_time" "v_args
                          }' | grep "nprload" | grep -v "grep" > $v_ps_file ;;

    *) F_exit 4 "$NPR_ARCH" ;;
esac
}

# ------------------------------------------------------------------------------
# Main
# ------------------------------------------------------------------------------
trap 'F_exit 10 HUP'   1
trap 'F_exit 10 INT'   2
trap 'F_exit 10 TERM' 15
trap 'F_exit 10 QUIT'  3

v_display_result="/tmp/check_loader.$$"

p_title="TRUE"
p_display="TRUE"
p_signal=""
p_ruleset=-1

# Check the Parameters
#
while [ $# -gt 0 ]
do
  case "$1" in
    -help|-usage) F_usage
                  F_exit 0
                  ;;
       -no-title) p_display="TRUE"
                  p_title="FALSE"
                  shift
                  ;;
             -db) p_display="FALSE"
                  p_db=$2
                  shift 2
                  ;;
 -ruleset-SIGHUP) p_display="FALSE"
                  p_ruleset=$2
                  p_signal="-1 "
                  shift 2
                  ;;
-ruleset-SIGTERM) p_display="FALSE"
                  p_ruleset=$2
                  p_signal="-15 "
                  shift 2
                  ;;
-ruleset-SIGKILL) p_display="FALSE"
                  p_ruleset=$2
                  p_signal="-9 "
                  shift 2
                  ;;
-ruleset-SIGSEGV) p_display="FALSE"
                  p_ruleset=$2
                  p_signal="-11 "
                  shift 2
                  ;;
              --) shift
                  break
                  ;;
               *) F_exit 1 "Unknow $1"
                  ;;
  esac
done

# Read in lots of important environment variables.
#
if [ -r $NPR_DIR/etc/env ] ; then
  . $NPR_DIR/etc/env
else
  F_exit 2 "NPR_DIR/etc/env"
fi

# Check the configuration file
#
v_loader_file="$NPR_CONF_DIR/loaders.conf"

if [ ! -r "$v_loader_file" ] ; then
  F_exit 2 "$v_loader_file"
fi

# Check the parameters
#
if [ "$p_display" = "FALSE" ] ; then
  if [ "$p_db" = "" ] ; then
    F_exit 5 "-db"
  fi

  if [ $p_ruleset -eq -1 ] ; then
    F_exit 5 "-ruleset-<signal>"
  fi
fi

# Result : tqlinfo -a ( LOADER processes only)
#
v_tqlinfo_file="/tmp/tqlinfo.$$"

echo /dev/null > $v_tqlinfo_file
tqlinfo -a 2> /dev/null | $NPR_NAWK '/LOADER/ {print $1" "$6" "$12}' > $v_tqlinfo_file
v_return=$?

if [ $v_return -ne 0 ] ; then
  F_exit 3 "$v_return"
fi

# Create the ps result file (ps -fu metrica | grep nprload)
#
F_create_ps_file

# Display the PID list
#
$NPR_NAWK ' 
  BEGIN {
    CONFIG_FILE=ARGV[1]
    TQLINFO_FILE=ARGV[2]
    PS_FILE=ARGV[3]

    # Put the loader configuration file in the array : config_list
    while ( ( getline < CONFIG_FILE ) > 0 )
    {
      # If title, commentary and empty line
      if ( ( $0 ~ /^#/ ) || ( $0 ~ /^$/ ) || ( $0 ~ /^----/ ) || ( $0 ~ /SPOOL DIRECTORY/ ) )
        continue

      gsub(" ", "", $1)
      gsub("	", "", $1)

      gsub(" ", "", $2)
      gsub("	", "", $2)

      # Help : config_list[RULESET|DB]=LABEL
      config_list[$1"|"$2]=substr($0, 15, 25)
    }
    close( CONFIG_FILE )


    # Put the tqlinfo file in the arrays : 
    #           ps_stime_list, ps_time_list, ps_ruleset_list
    while ( ( getline < TQLINFO_FILE ) > 0 )
    {
      # Help : tqlinfo_db[PID]=DATABASE
      # Help : tqlinfo_ppid[PID]=PPID

      gsub(" ", "", $1)
      gsub(" ", "", $2)
      gsub(" ", "", $3)
      tqlinfo_db[$2]=$3
      tqlinfo_ppid[$2]=$1
    }
    close( TQLINFO_FILE )


    # Put the ps file in the arrays : 
    #           ps_stime_list, ps_time_list, ps_ruleset_list
    while ( ( getline < PS_FILE ) > 0 )
    {
      # Help : ps_stime_list[PID]=stime
      # Help : ps_time_list[PID]=time
      # Help : ps_ruleset_list[PID]=ruleset

      gsub(" ", "", $1)
      ps_stime_list[$1]=$2
      ps_time_list[$1]=$3

      v_pos=index($0, "-ruleset")
      if ( v_pos == 0 )
        ps_ruleset_list[$1]="--"
      else
        ps_ruleset_list[$1]=substr($0, v_pos+9, 2)
	gsub(" ", "", ps_ruleset_list[$1])
    }
    close( PS_FILE )
  }

  END {
    # Create the final Array with the TQLINFO processes
    #
    for ( v_pid in tqlinfo_db )
    {
      d_pid=v_pid

      ps_stime_list[d_pid]   == "" ? d_stime="--:--:--"  : d_stime=ps_stime_list[d_pid] 
      ps_time_list[d_pid]    == "" ? d_time="--:--:--"   : d_time=ps_time_list[d_pid]
      ps_ruleset_list[d_pid] == "" ? d_ruleset="--"      : d_ruleset=ps_ruleset_list[d_pid]
      tqlinfo_db[d_pid]      == "" ? d_database="------" : d_database=tqlinfo_db[d_pid]
      tqlinfo_ppid[d_pid]    == "" ? d_ppid="----"       : d_ppid=tqlinfo_ppid[d_pid]
      config_list[d_ruleset"|"d_database] == "" ? d_label=" --------" : d_label=config_list[d_ruleset"|"d_database]

      d_key=sprintf("%s%.5d", d_database, d_ruleset)
      t_final[d_key]=sprintf("%6s  %6s  %8s  %11s  %12s  %8s  %s", 
		d_pid, d_ppid, d_stime, d_time, d_database, d_ruleset, d_label )
    }

    # Append or update the final Array with the CONFIGURATION ruleset 
    #
    for ( v_key in config_list )
    {
      d_database="------"
      d_pid="----" 

      split(v_key, t_key, "|")
      d_ruleset=t_key[1]
      d_database=t_key[2]

      for ( v_pid in ps_ruleset_list )
      {
        if ( ps_ruleset_list[v_pid] == d_ruleset )
          d_pid=v_pid
      }

      if ( (tqlinfo_db[d_pid] == d_database) ) {
        ps_stime_list[d_pid] == ""  ? d_stime="--:--:--" : d_stime=ps_stime_list[d_pid]
        ps_time_list[d_pid] == ""   ? d_time="--:--:--"  : d_time=ps_time_list[d_pid]
        tqlinfo_ppid[d_pid] == ""   ? d_ppid="----"      : d_ppid=tqlinfo_ppid[d_pid]
        config_list[d_ruleset"|"d_database] == "" ? d_label=" --------" : d_label=config_list[d_ruleset"|"d_database]
      }
      else
      {
        d_pid="----"
        d_stime="--:--:--"
        d_time="--:--:--"
        d_ppid="----"
        d_label=" --------"
      }

      d_key=sprintf("%s%.5d", d_database, d_ruleset)
      t_final[d_key]=sprintf("%6s  %6s  %8s  %11s  %12s  %8s  %s",
                d_pid, d_ppid, d_stime, d_time, d_database, d_ruleset, d_label )
    }
 
    # DISPLAY the result
    #
    for ( v_line in t_final )
      print t_final[v_line]
  }

 ' "$v_loader_file" "$v_tqlinfo_file" "$v_ps_file" | sort -k 6,6 > $v_display_result

# Display or kill -<signal> the process
#
if [ "$p_display" = "TRUE" ]  ; then
  # Display the title
  #
  if [ "$p_title" = "TRUE" ] ; then
    echo ""
    echo "                   LOADER PROCESSES REPORT"
    echo "                   -----------------------"
    echo ""
    echo "   PID  TQLPID     STIME         TIME      DATABASE   RULESET   LABEL"
    echo " --------------------------------------------------------------------"
  fi
 
  # Cat the result file
  #
  cat $v_display_result

else
  # DB name : Translate lowercase characters to uppercase
  #
  p_db=`echo "$p_db" | tr 'a-z' 'A-Z' `
  
  cat $v_display_result | while read v_pid v_tqlpid v_stime v_time v_db v_ruleset v_label
  do
    if [ "$v_db" = "$p_db" -a "$v_pid" != "----" ] ; then
      if [ $p_ruleset -eq 0 ] ; then
        kill $p_signal $v_pid
      else
        if [ $p_ruleset = $v_ruleset ] ; then
          kill $p_signal $v_pid 
        fi
      fi
    fi
  done
fi

F_exit 0
