#!/bin/sh
# ********************************************************************
# @(#) npr/binsrc/admin/nprimage.sh npr_r3.5.2.13:cset.005709:12:12@(#)
#
# FILENAME:	npr/binscr/admin/nprimage.sh
#
# ********************************************************************
#
#                   COPYRIGHT NOTICE
#
# This file remains the intellectual property of:
#
#              Vallent Software Systems UK
#                    Spencer House
#                    23 Sheen Road
#                 Richmond, Surrey, UK
#
# Copyright (c) 2005 Vallent Software Systems UK. All rights reserved.
#
# ********************************************************************
# NPR Admin
# 

# ------------------------------------------------------------------------------
# Exit Function 
# ------------------------------------------------------------------------------
F_exit() # Num_error , info+
{
  v_err=$1               # Error
  v_info=$2              # v_info+
  v_mess=""
 
  case $v_err in
    0)  v_mess="Metrica/NPR Image finished.\nFILE: $v_output_file";;
    1)  v_mess="Err  1 : Incorrect arguments ($v_info)";;
    2)  v_mess="Err  2 : Missing the file $v_info";;
    3)  v_mess="Err  3 : The environment variable $v_info is not setting";;
    4)  v_mess="Err  4 : You must be user $NPR_ADMIN_UID (user: $v_info)";;
    5)  v_mess="Err  5 : You must run the script on the server";;
   10)  v_mess="Err 10 : Received signal $v_info, terminating";;
    *)  v_mess="Err $v_err : $v_info";;
  esac

  # Don't display the finished message if v_err <= 5
  #
  if [ $v_err -gt 5 ] ; then
    # Put v_mess in the log file
    #
    F_print_log "$v_mess"

    if [ $v_err -eq 0 ]; then
      F_print_log "NPRIMAGE FINISHED SUCCESSFULLY"
    else
      F_print_log "NPRIMAGE FINISHED UNSUCCESSFULLY (Err : $v_err)"
    fi
  fi

  # Remove the tmp files
  #
  rm -f /tmp/*.$$.*

  if [ ! -z "$v_mess" ] ; then
    echo ""
    echo "$v_mess" >&2
  fi

  exit $v_err                              # Exit with status
}

# ------------------------------------------------------------------------------
# Usage Function
# ------------------------------------------------------------------------------
F_usage()
{
  usage="Usage : nprimage.sh [-system] [-loader] [-pas] \n\
                    [-npr] [-scheduler] [-archiver] [-dms] \n\
                    [-no-compress] [-file <filename>] [-help|-usage]\n\
                    \n\
            e.g. nprimage.sh -system -npr -scheduler -file /tmp/trace.out"
 

  echo ""
  echo "$usage" >&2
}

# ------------------------------------------------------------------------------
# Log and Sep Function
# ------------------------------------------------------------------------------
F_print_log() # string_log
{
  echo "(`date +%d%b%y_%H:%M:%S`) " $* >> $v_file_log
}

F_print_sep()
{
  echo "" >> $v_file_log
  echo " +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+-- " >> $v_file_log
  echo "" >> $v_file_log
}

# ------------------------------------------------------------------------------
# nprinfo_log Function
# ------------------------------------------------------------------------------
F_nprinfo_log()
{
  F_print_log " ==================== nprinfo ==================== "
  nprinfo >> $v_file_log
  F_print_sep
}

# ------------------------------------------------------------------------------
# tqladmin_log Function
# ------------------------------------------------------------------------------
F_tqladmin_log()
{
  F_print_log " ================= tqladmin -info ================ "
  tqladmin -info >> $v_file_log
  F_print_sep
}

# ------------------------------------------------------------------------------
# tqlinfo_log Function
# ------------------------------------------------------------------------------
F_tqlinfo_log()
{
  F_print_log " ==================  tqlinfo -a =================== " 

  tqladmin -info -tidy > /dev/null 2>&1
  tqlinfo -a >> $v_file_log 
  F_print_sep
}


# ------------------------------------------------------------------------------
# ps_log Function
# ------------------------------------------------------------------------------
F_ps_log()
{
  F_print_log " ===================  ps -fe  ===================== "

  case $NPR_ARCH in
    SUN4 | DECMIPS ) 
      ps | grep -v $$ >> $v_file_log 
    ;;
    SUN4SOLARIS)
      /usr/bin/ps -o "vsz pcpu time stime pid ppid fname comm args" -e | grep -v $$ >> $v_file_log 
    ;;
    DECALPHA)
      /usr/bin/ps -o "vsz pcpu time stime pid ppid comm args" -e | grep -v $$ >> $v_file_log 
    ;;
    RS6000 | SGIRIS | HP* ) 
      ps -fe | grep -v $$ >> $v_file_log 
    ;;
    LINUX86 )
      ps afe | grep -v $$ >> $v_file_log
    ;;
    *) F_print_log "Unknown architecture $NPR_ARCH"
    ;; 
  esac
  F_print_sep
} 

# ------------------------------------------------------------------------------
# top Function
# ------------------------------------------------------------------------------
F_top_log()
{
  F_print_log " ===================== top -d 2 ==================== "
  case $NPR_ARCH in
    SUN4SOLARIS) /usr/ucb/ps -aux | head >> $v_file_log ;;
    SUN4 | DECMIPS | LINUX86) ;; 
    DECALPHA) /usr/local/bin/top -d 2 >> $v_file_log ;;
         HP*) /usr/bin/top -d 2 >> $v_file_log ;;
           *) F_print_log "Unknown architecture $NPR_ARCH" ;;
  esac

  F_print_sep
}

# ------------------------------------------------------------------------------
# ipcs_log Function 
# ------------------------------------------------------------------------------
F_ipcs_log()
{
  F_print_log " ===================== ipcs -a ==================== "
  ipcs -a >> $v_file_log
  F_print_sep
}

# ------------------------------------------------------------------------------
# vmstat_log Function
# ------------------------------------------------------------------------------
F_vmstat_log()
{
  F_print_log " =================== vmstat -s ==================== " 
  vmstat -s >> $v_file_log
  F_print_sep
}

# ------------------------------------------------------------------------------
# iostat_log Function
# ------------------------------------------------------------------------------
F_iostat_log()
{
  F_print_log " =================== iostat  ==================== " 
  case $NPR_ARCH in
    SUN4SOLARIS) iostat -xtc >> $v_file_log ;;
        LINUX86) ;;
              *) iostat      >> $v_file_log ;;
  esac

  F_print_sep
}

# ------------------------------------------------------------------------------
# uptime_log Function
# ------------------------------------------------------------------------------
F_uptime_log()
{
  F_print_log " =================== uptime ==================== "
  uptime >> $v_file_log
  F_print_sep
}

# ------------------------------------------------------------------------------
# df_log  Function
# ------------------------------------------------------------------------------
F_df_log()
{
  F_print_log " ===================== df -k ====================== " 
  df -k >> $v_file_log
  F_print_sep
}

# ------------------------------------------------------------------------------
# env_log  Function
# ------------------------------------------------------------------------------
F_env_log()
{
  F_print_log " ====================== env ====================== "
  env >> $v_file_log
  F_print_sep
}

# ------------------------------------------------------------------------------
# ls_directory
# ------------------------------------------------------------------------------
F_ls_directory() # directory
{
  v_dir=$1

  if [ ! -d `dirname "$v_dir"` ]; then
    F_print_log "The directory $v_dir does not exist"
    return
  fi
 
  F_print_log " ================ ls -la $v_dir ================ "
  ls -la $v_dir >> $v_file_log 2>&1
  F_print_sep
}

# ------------------------------------------------------------------------------
# lastreboot_log  Function
# ------------------------------------------------------------------------------
F_lastreboot_log()
{
  F_print_log " ================== last reboot =============== " 
  last reboot | head >> $v_file_log
  F_print_sep
}

# ------------------------------------------------------------------------------
# xrdb_log  Function
# ------------------------------------------------------------------------------
F_xrdb_log()
{
  F_print_log " ================== xrdb -query ================= " 

  case $NPR_ARCH in
    DECMIPS | DECALPHA | RS6000 | SGIRIS | HP* ) 
       /usr/bin/X11/xrdb -query >> $v_file_log 2>&1
    ;;
    SUN4SOLARIS | SUN4)
       /usr/openwin/bin/xrdb -query >> $v_file_log 2>&1
    ;;
    LINUX86) 
       /usr/X11R6/bin/xrdb -query >> $v_file_log 2>&1
    ;;
    *) F_print_log "Unknown architecture $NPR_ARCH"
    ;;
  esac
  F_print_sep
}

# ------------------------------------------------------------------------------
# F_check_tqlserver Function
# ------------------------------------------------------------------------------
F_check_tqlserver()
{
  v_day=`date '+%b %d'`

  grep "$v_day" $TQL_SERVER_DIR/tqlserv.log | $NPR_NAWK '
    /Info : Database [A-Z0-9_]+ opened/                             { next }
    /Info : Database [A-Z0-9_]+ closed/                             { next }
    /Info : End$/                                                   { next }
    /Info : End.$/                                                  { next }
    /Info : Started, parent = /                                     { next }
    /Info : Server fully shutdown/                                  { next }
    /Info : Resetting signal flags/                                 { next }
    /Info : Resetting server shutdown flag/                         { next }
    /Info : Shutting down in /                                      { next }
    /Debug : In terminate_shared_finfo, shm_attached/               { next }
    /Info : Sending close query to finalise shutdown/               { next }
    /Small data pool overflow/                                      { next }
    /Warning : Parent process [0-9]+ has died/                      { next }
    /Warning : Caught signal 15, noting/                            { next }
    /Warning : Terminating due to previously caught signal/         { next }
    /Warning : Been blocking signals for longer than 20 seconds/    { next }
    /Warning : The block request came from/                         { next }
    /Debug : filer_init.. - not first user/                         { next }
    /Info : Attached memory volume .size/                           { next }
    /Debug : filer_init.. - first user/                             { next }
    /Debug : Entering filer_term/                                   { next }
    /Debug : Exiting filer_term/                                    { next }
    /Info : Shutting down database/                                 { next }
    / Repair : Checking index free chain/                           { next }
    / Repair : Sorting /                                            { next }
    / Repair : Checking data dictionary consistency/                { next }
    / Repair : Checking master file/                                { next }
    / Repair : Checking volume file/                                { next }
    / Repair : File [A-Z0-9_a-z]+ was closed/                       { next }
    / Repair : Fixing /                                             { next }
    / Repair : Repairing database /                                 { next } 
    / Repair : Repairing table /                                    { next }
    / Repair : Finished repairing table/                            { next }
    / Repair : Removing definition of temporary relation /          { next }
    / Repair : Rebuilding indexes on /                              { next }
    / Repair : Rebuilding system indexes/                           { next }
    / Repair : $/                                                   { next } 
    { print } '

    F_print_sep
}

# ------------------------------------------------------------------------------
# F_trace_file_log Function
# ------------------------------------------------------------------------------
F_trace_file_log()  # Number of lines, File name
{
  v_num=$1
  v_file=$2

  if [ ! -r "$v_file" ]; then
    F_print_log "The file `basename $v_file` does not exist"
    F_print_sep
    return
  fi

  v_file_result="/tmp/"`basename $v_file`".$v_num.$$.tmp"

  case $v_num in
    ALL) 
      F_print_log "Attach the file `basename $v_file`"
      echo $v_file >> $v_file_to_tar 
      ;;
    PAS_ONLY)
      cat $v_file | grep -i "alarm" >> $v_file_result
      echo $v_file_result >> $v_file_to_tar
      ;;
    TQL_PB_ONLY)
      F_print_log "Attach the problem in tqlserver.log"
      F_check_tqlserver >> $v_file_to_tar
      ;;
    FILTER_COMMENT)
      F_print_log "Attach (without comments) of the file `basename $v_file`"
      cat $v_file | egrep -v "^#" >> $v_file_result
      echo $v_file_result >> $v_file_to_tar
      ;;
    *)
      F_print_log "Attach last $v_num lines of the file `basename $v_file`"
      tail "-"$v_num $v_file >> $v_file_result
      echo $v_file_result >> $v_file_to_tar
    ;;
  esac

  F_print_sep
}

# ------------------------------------------------------------------------------
# F_loader Function
# ------------------------------------------------------------------------------
F_loader()
{
  F_print_log " ==========  Loaders processes ========== "
  $NPR_DIR/bin/admin/check_loader.sh >> $v_file_log

  F_print_sep
}

# ------------------------------------------------------------------------------
# crontab_log Function
# ------------------------------------------------------------------------------
F_crontab_log()
{
  F_print_log " ================== crontab -l ================== "

  if [ ! -d $NPR_DIR/crontab ] ; then
     mkdir $NPR_DIR/crontab
  fi

  v_form_H=`date +%H`
  v_form_M=`date +%M`
  v_form_S=`date +%S`

  v_form_time=`date +%y%b%d`"."$v_form_H""$v_form_M""$v_form_S

  v_crontab_file=$NPR_DIR/crontab/crontab.$v_form_time

  crontab -l > $v_crontab_file 2>&1
  v_return=$?

  if [ $v_return -ne 0 ]; then
    F_print_log "Copy crontab Failed (Err = $v_return)"
  else
    F_print_log "Attach the crontab result" 
    echo $v_crontab_file >> $v_file_to_tar
  fi
  F_print_sep
}

# ------------------------------------------------------------------------------
# F_store_core Function
# ------------------------------------------------------------------------------
F_store_core() # Directory
{
  v_type=$1
  v_directory=$2

  # If store directory does not exist
  #
  if [ ! -d $NPR_LOG_DIR/crashes ] ; then
     mkdir $NPR_LOG_DIR/crashes
  fi

  v_form_H=`date +%H`
  v_form_M=`date +%M`
  v_form_S=`date +%S`

  v_form_time=`date +%y%b%d`"."$v_form_H""$v_form_M""$v_form_S

  F_print_log "Check the core files in $v_directory"

  # Find core file in the Directory parameter 
  #
  if [ -d "$v_directory" ]; then
    v_index=1
    time=`date`

    for one_core in `find $v_directory -name core -print`
    do
      F_print_log "Move core file $v_index in crashes directory"
      mv $one_core $NPR_LOG_DIR/crashes/core.$v_type.$v_form_time.$v_index
      echo $NPR_LOG_DIR/crashes/core.$v_type.$v_form_time.$v_index >> $v_file_to_tar
      v_index=`expr $v_index + 1`
    done
  fi

}

# ------------------------------------------------------------------------------
# list_display_client Function
# ------------------------------------------------------------------------------
F_list_display_client()
{
  v_list_display=""

  F_print_log " ================ Query in LRUNNING ================ "

  # Do a query in the Admin database to have the DISPLAY list  
  cat <<-END_SCRIPT > $v_file_query
	set %pass "$NPR_PASSWORD" ;
	OPEN $NPR_ADMIN_DB ;
	>> $v_file_log DISPLAY PID#, HOST, NPRUSER, SCREEN, NPRSTART FROM LRUNNING;
	CLOSE ;
END_SCRIPT

  v_list_display=`qtip -user $NPR_USER -scriptFile $v_file_query`

  F_print_sep

}

# ------------------------------------------------------------------------------
# F_check_db Function
# ------------------------------------------------------------------------------
F_check_db()
{
  F_print_log " ================ Databases Status ================ "

  for v_base in "$NPR_ADMIN_DB" "$NPR_DB"
  do
    tqladmin -checkdb -database $v_base > /dev/null 2>&1
    v_return=$?
    if  [ $v_return -ne 0 ]; then
      F_print_log "The database $v_base is NOK"
    else
      F_print_log "The database $v_base is OK"
    fi
  done

  F_print_sep
}

# ------------------------------------------------------------------------------
# F_check_volume Function 
# ------------------------------------------------------------------------------
F_check_volume()
{
  F_print_log " ================ $1 VOLUME(S) ================ "
 
  v_tmpvol=/tmp/vols.$$.res

  cat <<- END_TSL > $v_tmpvol
	printer OUTPUT=file, FILENAME="$v_file_log", APPEND=YES
	printer on

	query open $1 ;
	query %print %maxvols ;
	declare maxvols [print]
	margin 2 150

	# find number of volumes
	declare volidx 0

	println "VOLUME    NAME             PATH"
	println "---------------------------------------------------------------------------"

	repeat
	  declare volname locate(volidx)
	  if volname <> ""
	    declare volpath locate(volname)
	    println volidx::"%-10v" volname::"%-16v " volpath::"%-v"
	  endif
	  set volidx volidx+1
	until volidx = maxvols
	query close $1;

	printer off
END_TSL

  tsl -nowin $v_tmpvol
  rm -f $v_tmpvol

  F_print_sep
}

# ------------------------------------------------------------------------------
# F_check_corruption Function
# ------------------------------------------------------------------------------
F_check_corruption()
{
  F_print_log " ====== Check Corruption - nprload.log =========== "

  if [ -r $NPR_LOG_DIR/nprload.log ]; then 
    egrep -i "index may be corrupt|\
inconsistency in the index|\
index probably corrupted|\
Corrupt or inconsistent|\
File position is invalid|\
Filer error|\
Expected end of report block|\
Lock would cause deadlock|\
Row not found|\
Missing identification string" $NPR_LOG_DIR/nprload.log  | sort -u  >> $v_file_log
  else
    F_print_log "The file nprload.log does not exist"
  fi

  F_print_log " ====== Check Corruption - tsl.log ============== "
  if [ -r $NPR_LOG_DIR/tsl.log ]; then
    egrep -i "index probably corrupted|\
File position is invalid|\
Query Interpreter has died" $NPR_LOG_DIR/tsl.log | sort -u  >> $v_file_log
  else
    F_print_log "The file tsl.log does not exist"
  fi

  F_print_log " ====== Check Corruption - tqlserver.log ======== "
  if [ -r $TQL_SERVER_DIR/tqlserv.log ]; then
    F_check_tqlserver >> $v_file_log 
  else
    F_print_log "The file tqlserv.log does not exist"
  fi

  F_print_sep

}

# ------------------------------------------------------------------------------
# F_transfert_table Function
# ------------------------------------------------------------------------------
F_transfert_table()
{
  v_db=$1 
  v_list_table=$2
  v_resultfile=/tmp/$2.$$.res

  # Create the tsl script
  #
  cat <<-END_SCRIPT > $v_file_transfert 
	abort off

        query set %pass "[$NPR_PASSWORD_ADMIN]" ;
	query open $v_db;
	if not %qok
	  stop 1
	endif
 
	# Set properties for a CSV file
	transfer property set delimiter=";" terminator=0

	# UnLoad the CSV file
	transfer unload $v_list_table "$v_resultfile"
 
	ifok
	  query close $v_db ;
	  abort on
	  stop 0
	else
	  query close $v_db ;
	  abort on
	  stop 2 
	endif
END_SCRIPT

  # Extract the data
  #
  for v_onetable in v_list_table
  do
    F_print_log "Attach the unload result of the table $v_list_table"
    tsl -nowin -user DBA $v_file_transfert
  done
}

# ------------------------------------------------------------------------------
# main 
# ------------------------------------------------------------------------------
trap 'F_exit 10 HUP'   1 
trap 'F_exit 10 INT'   2 
trap 'F_exit 10 QUIT'  3 
trap 'F_exit 10 TERM' 15

# Read in lots of important environment variables.
#
if [ -r $NPR_DIR/etc/env ] ; then
  . $NPR_DIR/etc/env
else
  F_exit 2 "NPR_DIR/etc/env"
fi

# Check the parameters
# 
v_loader=false
v_pas=false
v_dms=false
v_scheduler=false
v_archiver=false
v_gap=false
v_system=false
v_npr=false
v_compress=true

v_form_H=`date +%H`
v_form_M=`date +%M`
v_form_S=`date +%S`

v_form_time=`date +%y%b%d`"."$v_form_H""$v_form_M

v_output_file=/tmp/tar_result.$v_form_time

while [ $# -gt 0 ]
do
  case "$1" in
    -help|-usage) F_usage
                  exit 0
                  ;;
            -npr) v_npr=true
                  shift
                  ;;
         -loader) v_loader=true
                  shift
                  ;;
            -pas) v_pas=true
                  shift
                  ;;
            -dms) v_dms=true
                  shift
                  ;;
      -scheduler) v_scheduler=true
                  shift
                  ;;
       -archiver) v_archiver=true
                  shift
                  ;;
            -gap) v_gap=true
                  shift
                  ;;
         -system) v_system=true
                  shift
                  ;;
    -no-compress) v_compress=false
                  shift
                  ;;
          -file) v_output_file=$2
                  shift 2
                  ;;
              --) shift
                  break
                  ;;
               *) F_exit 1 "Unknow $1" 
                  ;;
  esac
done

# Setup databases and user/password
#
if [ -z "$NPR_DB" ]; then
  F_exit 3 "NPR_DB"
fi

if [ -z "$NPR_ADMIN_DB" ]; then
  F_exit 3 "NPR_ADMIN_DB"
fi

if [ -z "$NPR_USER" ]; then
  F_exit 3 "NPR_USER"
fi

env | grep "NPR_PASSWORD" > /dev/null
if [ $? -ne 0 ] ; then
  F_exit 3 "NPR_PASSWORD"
fi

# Global
# 
v_file_log=/tmp/file_log.$$.tmp

v_file_query=/tmp/file_query.$$.tmp
v_file_transfert=/tmp/file_transfert.$$.tmp
v_file_to_tar=/tmp/file_to_tar.$$.tmp

# BUG58831 : Error message when creating result file
#			complaining on Cannot open /tmp/file_to_tar.3014.tmp
echo /dev/null > $v_file_to_tar

# Check that the user is metrica
#
v_id=`id | $NPR_NAWK '{ print \$1 }' | sed -e 's/uid=[0-9]*(//' -e 's/)//'`
if [ $v_id != $NPR_ADMIN_UID ] ; then
  F_exit 4 $v_id
fi

# Check if SERVER
#
if [ "$NPR_USAGE_MODE" != "SERVER" ] ; then
  F_exit 5
fi

# Trace
#
F_print_log "NPRIMAGE STARTED (pid $$) with $*"


# ======= INFORMATIONS ALWAYS PROVIDED =======
#
F_nprinfo_log
F_crontab_log
F_env_log


# =============== SYSTEM LOG =================
#
if [ $v_system = true ] ; then
  F_df_log
  F_ps_log
  F_lastreboot_log
  F_ipcs_log
  F_vmstat_log
  F_iostat_log
  F_uptime_log
  F_top_log
  F_xrdb_log

  F_trace_file_log 50 /var/adm/messages
  F_trace_file_log FILTER_COMMENT /etc/system
fi

# =============== NPR LOG ==================
#
if [ $v_npr = true ] ; then
  F_tqladmin_log
  F_tqlinfo_log

  F_list_display_client

  F_ls_directory "$NPR_DIR/*.pid"
  F_ls_directory "$NPR_DIR/*.lock"

  F_store_core SERVER $TQL_SERVER_DIR
  F_store_core CLIENT $TQL_CLIENT_DIR
  F_store_core NPR    $NPR_DIR

  F_trace_file_log ALL       $NPR_LOG_DIR/tsl.log
fi

# ============== LOADER LOG ==============
#
if [ $v_loader = true ] ; then
  F_loader
  F_transfert_table "$NPR_ADMIN_DB" "LOADMAP HIERLIST INFRULES"

  F_trace_file_log 200       $NPR_LOG_DIR/nprload.audit
  F_trace_file_log 500       $NPR_LOG_DIR/nprload.log
fi

# =============== PAS LOG ===============
#
if [ $v_pas = true ] ; then
  F_transfert_table "$NPR_ADMIN_DB" "A_TARGET A_GRP A_NW A_HIST"

  F_ls_directory "$NPR_TSL_DIR/detect/*.tsl"
  F_ls_directory "$NPR_TMP_DIR/failsafe.alarms.*"

  F_trace_file_log PAS_ONLY $NPR_LOG_DIR/nprload.log
  F_trace_file_log ALL      $NPR_LOG_DIR/npralarmd.log
  F_trace_file_log ALL      $NPR_LOG_DIR/npralarmsched.log
fi

# =============== DMS LOG ===============
#
if [ $v_dms = true ] ; then
  F_check_db
  F_check_volume $NPR_DB
  F_check_volume $NPR_ADMIN_DB

  F_check_corruption

  F_trace_file_log ALL  $TQL_SERVER_DIR/tqlserv.log
fi

# =========== SCHEDULER LOG ============= 
#
if [ $v_scheduler = true ] ; then
  F_transfert_table "$NPR_ADMIN_DB" "ACTIVITY"

  F_trace_file_log ALL       $NPR_LOG_DIR/nprsched.audit
  F_trace_file_log ALL       $NPR_LOG_DIR/nprsched.log
fi

# =========== ARCHIVER LOG =============
#
if [ $v_archiver = true ] ; then
  F_transfert_table "$NPR_ADMIN_DB" "ARCHIVE"

  F_trace_file_log ALL       $NPR_LOG_DIR/nprarch.audit
  F_trace_file_log ALL       $NPR_LOG_DIR/nprarch.log
fi

# =========== GAP LOG =============
#
if [ $v_gap = true ] ; then
  F_transfert_table "$NPR_ADMIN_DB" "GAPTABS"

  F_trace_file_log ALL       $NPR_LOG_DIR/nprgap.log
fi


# Tar / compress all the files
#
F_print_log "The tar file created contain : "
cat $v_file_to_tar >> $v_file_log

if [ $v_compress = false ]; then
  tar -cf - $v_file_log `cat $v_file_to_tar` > $v_output_file
else
  v_output_file=$v_output_file".Z"
  tar -cf - $v_file_log `cat $v_file_to_tar` | compress > $v_output_file
fi

F_exit 0
